


function M = minmaxnorm(M,varargin)

%   MinMax normalization
%   
%   MNORM = MINMAXNORM(M) normalizes the data in vector M by subtracting 
%   from it its minimum value and dividing the result by the range of the 
%   data in vector M, thus producing a scaled version of M, i.e. MNORM, 
%   whose maximum is 1 and minimum is 0. If M is an array, MINMAXNORM works 
%   on each column separately.  
%   
%   MNORM = MINMAXNORM(M,'columns') is the same as MNORM = MINMAXNORM(M).
%   
%   MNORM = MINMAXNORM(M,'array') works on the entire array (and not each 
%   column separately).
%   
%   MNORM = MINMAXNORM(...,LIMITS) scales the data not to 0 to 1, but 
%   rather to limits provided in the two-element vector LIMITS. For example 
%   if LIMITS = [7 to 11], MINMAXNORM produces a scaled version of M, whose 
%   maximum is 11 and minimum is 7.
%   
%   
%   Copyright 2009 Aleksander Sobolewski
%      
%   See also (other m-files in the package): CTC, CTCVIEWER, PIN2ZERO


if nargin>1 && strcmp('array',varargin{1})
    MIN = min(M(:));
    MAX = max(M(:));
    M = (M-MIN)./(MAX-MIN); 
else
    M = (M-repmat(min(M),[size(M,1),1,1]))./(repmat(max(M),[size(M,1),1,1])-repmat(min(M),[size(M,1),1,1])); 
end

if nargin>2 
    M = M*(varargin{2}(2)-varargin{2}(1))+varargin{2}(1);
end