
function data = pin2zero(data,varargin)

%   Bringing a series' baseline to zero.
%   
%   P = PIN2ZERO(M) subtracts the first element of vector M (e.g. containing time 
%   series data), from the data contained in the vector, thus bringing the starting 
%   value of the time series to 0. 
%   
%   P = PIN2ZERO(M,N) subtracts from M not the first element, but the element N (if 
%   N is a scalar) or the mean of elements indexed by N, if N is a vector. For 
%   example, if M is a 200 element vector and N = 1:50, PIN2ZERO subtracts from M 
%   the mean of its first 50 elements, thus bringing the time series first 50 
%   elements to equal (on average) 0. 
%   
%   If M is an array, PIN2ZERO works on each column separately. 
%   
%   Copyright 2009 Aleksander Sobolewski
%      
%   See also (other m-files in the package): CTC, CTCVIEWER, MINMAXNORM


if nargin>1; sweep = varargin{1}; else sweep = 1; end

origclass = class(data);

data = single(data);
data = data - repmat(mean(data(sweep,:,:,:,:),1),[size(data,1) 1 1 1 1]);

data = eval([origclass '(data)']);

    